//
//  ViewController.swift
//  Zahlenratenspiel
//
//  Created by Holger Hinzberg on 18.09.17.
//  Copyright © 2017 Holger Hinzberg. All rights reserved.
//

import UIKit

class ViewController: UIViewController
{
    // Verbindungen zu den Steuerelementen
    // der grafischen Oberfläche
    @IBOutlet var schiebereglerLabel: UILabel!
    @IBOutlet var rateversucheLabel: UILabel!
    @IBOutlet var rateresultatLabel: UILabel!
    @IBOutlet var eingabeTextfeld: UITextField!
    @IBOutlet var schieberegler:UISlider!
    @IBOutlet var rateButton:UIButton!
    
    // Zwei Eigenschaften für das Spiel
    var zufallszahl = 0
    var rateversuche = 0
    
    @IBOutlet var verbleibendeSekundenProgress: UIProgressView!

    
    var startzeit: Date?
    let spielzeitInSekunden: Int = 30
    var timer:Timer?
    
    // Ein Mitteilungsfenster für das Spiel
    var alertController: UIAlertController?
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        
        // Das Mitteilungsfenster konfigurieren
        self.alertController = UIAlertController(title: "Zeit abgelaufen",
          message: "Versuche es noch einmal ", preferredStyle: .alert)
        
        // Eine Aktion, um die Felder zu leeren
        let weiterAktion
            = UIAlertAction(title: "Weiter", style: UIAlertActionStyle.default)
        {
            action in
            self.rateresultatLabel.text = "Wähle die größte mögliche Zahl"
            self.rateversucheLabel.text = "und berühre START zum Spielen"
            self.rateButton.isEnabled = false
            self.verbleibendeSekundenProgress.progress = 1
        }
        
        // Die Aktion dem UIAlertController anhängen
        self.alertController?.addAction(weiterAktion)

        
        self.schiebereglerLabel.text = "50"
        self.rateresultatLabel.text = "Wähle die höchste mögliche Zahl"
        self.rateversucheLabel.text = "und berühre START zum spielen"
        
        // Den Button aus dem Code deaktivieren
        self.rateButton.isEnabled = false
        
        self.verbleibendeSekundenProgress.progress = 1
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @IBAction func schiebereglerBewegt(_ sender: Any)
    {
        // Den eingestellten Wert vom Schieberegler holen
        let wert = Int(self.schieberegler.value)
        // Den Wert in das Bezeichnungsfeld schreiben
        self.schiebereglerLabel.text = "\(wert)"
    }
    
    @IBAction func startButtonBeruehrt(_ sender: Any)
    {
        self.timerStarten()
        
        // Den eingestellten Wert vom Schieberegler holen
        let wert = UInt32(self.schieberegler.value)
        
        // Die Zufallszahl ermitteln und in der
        // Eigenschaft der Klasse ablegen
        self.zufallszahl = Int(arc4random_uniform(wert) + 1)
        
        // Den Zähler zurück setzen
        self.rateversuche = 0
        
        // Ausgabe auf den Bezeichnungsfeldern
        self.rateversucheLabel.text = "Neues Spiel - Neues Glück"
        self.rateresultatLabel.text = "Es kann losgehen"
        
        // Den Button aus dem Code aktivieren
        self.rateButton.isEnabled = true
        
        // Zur Kontroller: Ausgabe der Zufallszahl
        // auf der Konsole
        print(self.zufallszahl)
    }
    
    func timerStarten()
    {
        // Den Startzeitpunkt merken
        self.startzeit = Date()
        
        // Einen eventuell vorhandenen Timer anhalten
        self.timer?.invalidate()
        
        self.timer = Timer.scheduledTimer(withTimeInterval: 0.5, repeats: true)
        {
            timer in
            
            let jetzt = Date()
            let interval = jetzt.timeIntervalSince(self.startzeit!)
            let sekunden = Int(interval)
            
            // Ausgabe zur Kontrolle
            print("\(sekunden)")
            
            let verbleibendeSekunden = self.spielzeitInSekunden - sekunden
            let progressWert = Float(verbleibendeSekunden) / Float(self.spielzeitInSekunden)
            self.verbleibendeSekundenProgress.progress = progressWert
            
            if  sekunden >= self.spielzeitInSekunden
            {
                self.timer?.invalidate()
                print("Zeit abgelaufen")
                self.present(self.alertController!, animated: true)
            }
        }
    }
    
    @IBAction func ratenButtonBeruehrt(_ sender: Any)
    {
        let text = self.eingabeTextfeld.text
        
        // Stelle sicher, dass text ungleich nil ist
        // Wenn nicht, verlasse die Methode
        guard text != nil else
        {
            return
        }
        
        // Stelle sicher, dass text in einen Int
        // umgewandelt werden kann.
        // Wenn nicht, verlasse die Methode
        guard let wert = Int(text!) else
        {
            return
        }
        
        // Ein weiterer Rateversuch
        self.rateversuche += 1
        
        if self.rateversuche == 1
        {
            self.rateversucheLabel.text = "Das war der erste Versuch"
        }
        else
        {
            self.rateversucheLabel.text = "Das waren \(self.rateversuche) Versuche"
        }
        
        if wert < self.zufallszahl
        {
            self.rateresultatLabel.text = "Die gesuchte Zahl ist größer"
        }
        else if wert > self.zufallszahl
        {
            self.rateresultatLabel.text = "Die gesuchte Zahl ist kleiner"
        }
        else
        {
            self.timer?.invalidate()
            self.rateresultatLabel.text = "Bravo! Das war richtig"
        }
    }
}

